@@ -5,7 +5,7 @@
    drvcairo.h : This file is part of pstoedit
    Class declaration for the cairo driver.
    
-   Copyright (C) 2009 Dan McMahill dan_AT_mcmahill_DOT_net
+   Copyright (C) 2009 - 2011 Dan McMahill dan_AT_mcmahill_DOT_net
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,9 +35,9 @@ class drvCAIRO : public drvbase {
   ~drvCAIRO(); // Destructor
   class DriverOptions : public ProgramOptions {
   public:
-    Option < bool, BoolTrueExtractor > pango;
-    Option < RSString, RSStringValueExtractor > funcname;
-    Option < RSString, RSStringValueExtractor > header;
+    OptionT < bool, BoolTrueExtractor > pango;
+    OptionT < RSString, RSStringValueExtractor > funcname;
+    OptionT < RSString, RSStringValueExtractor > header;
     DriverOptions(): 
       pango(true,"-pango",0,0,"use pango for font rendering",0,false),
       funcname(true,"-funcname","string",0,
