@@ -2,7 +2,7 @@
    drvSWF.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2011 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,7 +32,10 @@
 //static bool cubic = false;
 
 #include "mingpp.h"
-#include "ming_config.h"
+
+/* Use png library */
+#define USE_PNG 1
+// #include "ming_config.h"
 
 #if defined(_WIN32)
 extern "C" {
@@ -718,4 +721,4 @@ static DriverDescriptionT < drvSWF > D_SWF("swf",	//
 										   false	/*clipping */
 										   );
 #endif
- 
\ No newline at end of file
+ 
