@@ -5,7 +5,7 @@
    drvtext.h : This file is part of pstoedit
    Class declaration for a text oriented output driver 
 
-   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2011 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,9 +36,9 @@ public:
 	~drvTEXT(); // Destructor
 	class DriverOptions : public ProgramOptions { 
 	public:
-		Option < int, IntValueExtractor >pageheight;
-		Option < int, IntValueExtractor >pagewidth;
-		Option < bool, BoolTrueExtractor> dumptextpieces;
+		OptionT < int, IntValueExtractor >pageheight;
+		OptionT < int, IntValueExtractor >pagewidth;
+		OptionT < bool, BoolTrueExtractor> dumptextpieces;
 
 		DriverOptions() :
 			pageheight(true,"-height", "number",0, "page height in terms of characters",0,200),
