@@ -6,7 +6,7 @@
    Class declaration for a VTK output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2011 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
 	~drvVTK(); // Destructor
 	class DriverOptions : public ProgramOptions {
 	public:
-		Option < int, IntValueExtractor >VTKeoption;
+		OptionT < int, IntValueExtractor >VTKeoption;
 		DriverOptions(): 
 			VTKeoption(true,"-VTKeoption","integer",0,"just an example",0,99)
 		{
