@@ -4,7 +4,7 @@
 
    Copyright (C) 1996,1997 Jens Weber, rz47b7_AT_PostAG.DE
    Copyright (C) 1998 Thorsten Behrens and Bjoern Petersen
-   Copyright (C) 1998 - 2009 Wolfgang Glunz
+   Copyright (C) 1998 - 2011 Wolfgang Glunz
    Copyright (C) 2000 Thorsten Behrens
 
     This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,46 @@
 #define M_PI		3.14159265358979323846
 #endif
 
+#if defined(_BIG_ENDIAN)
+WORD LittleEndian_Word(WORD w)
+{
+	union {
+		WORD data;
+		BYTE b[2];
+	} u1, u2;
+
+	u1.data = w;
+	u2.b[0] = u1.b[1];
+	u2.b[1] = u1.b[0];
+	return u2.data;
+}
+
+DWORD32 LittleEndian_Dword32(DWORD32 dw)
+{
+	union {
+		DWORD32 data;
+		BYTE b[4];
+	} u1, u2;
+
+	u1.data = dw;
+	u2.b[0] = u1.b[3];
+	u2.b[1] = u1.b[2];
+	u2.b[2] = u1.b[1];
+	u2.b[3] = u1.b[0];
+	return u2.data;
+}
+
+#else
+WORD LittleEndian_Word(WORD w)
+{
+	return w;
+}
+
+DWORD32 LittleEndian_Dword32(DWORD32 dw)
+{
+	return dw;
+}
+#endif /* defined(_BIG_ENDIAN) */
 
 
 //
@@ -80,6 +120,7 @@ struct PLACEABLEHEADER {
 	DWORD32 reserved;
 	WORD checksum;
 };
+#pragma pack()
 
 static const char description[] = "generated by WMF/EMF backend of pstoedit\0input\0\0"; //lint !e840 //usage of nul char in string
 
@@ -450,14 +491,14 @@ drvWMF::~drvWMF()
 		if ((inFile = fopen(tempName.value(), "rb")) != 0L) {
 			if (outFile != 0L) {
 				// setup header
-				pHd.key = PLACEABLEKEY;
-				pHd.hmf = 0;
-				pHd.left = (WORD) minX;
-				pHd.top = (WORD) minY;
-				pHd.right = (WORD) maxX;
-				pHd.bottom = (WORD) maxY;
-				pHd.inch = 12;
-				pHd.reserved = 0;
+				pHd.key = LittleEndian_Dword32(PLACEABLEKEY);
+				pHd.hmf = LittleEndian_Word(0);
+				pHd.left = LittleEndian_Word((WORD) minX);
+				pHd.top = LittleEndian_Word((WORD) minY);
+				pHd.right = LittleEndian_Word((WORD) maxX);
+				pHd.bottom = LittleEndian_Word((WORD) maxY);
+				pHd.inch = LittleEndian_Word(12);
+				pHd.reserved = LittleEndian_Dword32(0);
 
 				// calculate checksum
 				checksum = 0;
@@ -465,7 +506,7 @@ drvWMF::~drvWMF()
 				for (unsigned int i = 0; i < 10; i++)
 					checksum ^= checksumField[i];
 
-				pHd.checksum = checksum;
+				pHd.checksum = LittleEndian_Word(checksum);
 
 				// write header
 				if (fwrite(&pHd, PLACEABLESIZE , 1, outFile) != 1) {
@@ -1037,7 +1078,7 @@ void drvWMF::show_text(const TextInfo & textinfo)
 		maxStatus = 1;
 	}
 
-	unsigned int textLen = strlen(textinfo.thetext.value());
+	size_t textLen = strlen(textinfo.thetext.value());
 	if (options->pruneLineEnds) {
 		/* check for '#' at lineend */
 		if (textLen > 0 && textinfo.thetext.value()[textLen - 1] == '#') {
